- Resuts -> Results
- outputed -> outputted
- specifiecd -> specified
- TURE -> TRUE
- specifed -> specified
- Pointion -> Position
- Arrary -> Array
- elasped -> elapsed
- paramter -> parameter
- Sumbit -> Submit

Cc: Michael D Kinney <michael.d.kin...@intel.com>
Cc: Liming Gao <liming....@intel.com>
Contributed-under: TianoCore Contribution Agreement 1.0
Signed-off-by: Gary Lin <g...@suse.com>
---
 MdePkg/Include/IndustryStandard/TcgPhysicalPresence.h                  |  6 
+++---
 MdePkg/Include/Library/SmmPeriodicSmiLib.h                             |  4 
++--
 MdePkg/Include/Protocol/HiiConfigKeyword.h                             |  2 +-
 MdePkg/Include/Protocol/HiiDatabase.h                                  |  4 
++--
 MdePkg/Include/Protocol/Kms.h                                          | 10 
+++++-----
 MdePkg/Library/BaseUefiDecompressLib/BaseUefiDecompressLib.c           |  8 
++++----
 MdePkg/Library/BaseUefiDecompressLib/BaseUefiDecompressLibInternals.h  |  2 +-
 MdePkg/Library/DxeExtractGuidedSectionLib/DxeExtractGuidedSectionLib.c |  2 +-
 MdePkg/Library/DxeIoLibCpuIo2/IoLib.c                                  |  2 +-
 MdePkg/Library/DxeIoLibEsal/IoLib.c                                    |  2 +-
 MdePkg/Library/DxePciLibEsal/PciLib.c                                  |  2 +-
 MdePkg/Library/DxePciSegmentLibEsal/PciLib.c                           |  2 +-
 MdePkg/Library/PeiExtractGuidedSectionLib/PeiExtractGuidedSectionLib.c |  4 
++--
 MdePkg/Library/PeiPciLibPciCfg2/PciLib.c                               |  2 +-
 MdePkg/Library/SmmIoLibSmmCpuIo2/IoLib.c                               |  2 +-
 MdePkg/Library/SmmMemoryAllocationLib/MemoryAllocationLib.c            |  2 +-
 MdePkg/Library/SmmPciLibPciRootBridgeIo/PciLib.c                       |  2 +-
 MdePkg/Library/SmmPeriodicSmiLib/SmmPeriodicSmiLib.c                   |  2 +-
 MdePkg/Library/UefiPciLibPciRootBridgeIo/PciLib.c                      |  2 +-
 19 files changed, 31 insertions(+), 31 deletions(-)

diff --git a/MdePkg/Include/IndustryStandard/TcgPhysicalPresence.h 
b/MdePkg/Include/IndustryStandard/TcgPhysicalPresence.h
index 80ae7d3..7a500e2 100644
--- a/MdePkg/Include/IndustryStandard/TcgPhysicalPresence.h
+++ b/MdePkg/Include/IndustryStandard/TcgPhysicalPresence.h
@@ -41,8 +41,8 @@ WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER 
EXPRESS OR IMPLIED.
 #define TCG_PP_RETURN_TPM_OPERATION_RESPONSE_FAILURE                   1
 
 //
-// TCG PP definition of return code for Sumbit TPM Request to Pre-OS 
Environment
-// and Sumbit TPM Request to Pre-OS Environment 2
+// TCG PP definition of return code for Submit TPM Request to Pre-OS 
Environment
+// and Submit TPM Request to Pre-OS Environment 2
 //
 #define TCG_PP_SUBMIT_REQUEST_TO_PREOS_SUCCESS                                 
 0
 #define TCG_PP_SUBMIT_REQUEST_TO_PREOS_NOT_IMPLEMENTED                         
 1
@@ -126,4 +126,4 @@ WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER 
EXPRESS OR IMPLIED.
 
 #define TCG2_PHYSICAL_PRESENCE_VENDOR_SPECIFIC_OPERATION                       
  128
 
-#endif
\ No newline at end of file
+#endif
diff --git a/MdePkg/Include/Library/SmmPeriodicSmiLib.h 
b/MdePkg/Include/Library/SmmPeriodicSmiLib.h
index dfdb5eb..2bad2b7 100644
--- a/MdePkg/Include/Library/SmmPeriodicSmiLib.h
+++ b/MdePkg/Include/Library/SmmPeriodicSmiLib.h
@@ -79,7 +79,7 @@ PeriodicSmiExit (
   If this function is not called from within an enabled periodic SMI handler, 
   then 0 is returned.
 
-  @return  The actual time in 100ns units elasped since this function was
+  @return  The actual time in 100ns units elapsed since this function was
            called.  A value of 0 indicates an unknown amount of time.
 
 **/
@@ -95,7 +95,7 @@ PeriodicSmiYield (
   PeriodicSmiDisable().
 
   @param[in] Context      Content registered with PeriodicSmiEnable().
-  @param[in] ElapsedTime  The actual time in 100ns units elasped since 
+  @param[in] ElapsedTime  The actual time in 100ns units elapsed since
                           this function was called.  A value of 0 indicates 
                           an unknown amount of time.
                             
diff --git a/MdePkg/Include/Protocol/HiiConfigKeyword.h 
b/MdePkg/Include/Protocol/HiiConfigKeyword.h
index 69280b8..208336c 100644
--- a/MdePkg/Include/Protocol/HiiConfigKeyword.h
+++ b/MdePkg/Include/Protocol/HiiConfigKeyword.h
@@ -152,7 +152,7 @@ EFI_STATUS
   @retval EFI_SUCCESS             The specified action was completed 
successfully.
   
   @retval EFI_INVALID_PARAMETER   One or more of the following are TRUE:
-                                  1.Progress, ProgressErr, or Resuts is NULL.
+                                  1.Progress, ProgressErr, or Results is NULL.
                                   2.Parsing of the KeywordString resulted in 
an error. See
                                     Progress and ProgressErr for more data.
   
diff --git a/MdePkg/Include/Protocol/HiiDatabase.h 
b/MdePkg/Include/Protocol/HiiDatabase.h
index 474d840..5ba50f8 100644
--- a/MdePkg/Include/Protocol/HiiDatabase.h
+++ b/MdePkg/Include/Protocol/HiiDatabase.h
@@ -214,7 +214,7 @@ EFI_STATUS
 
   @param Handle               An array of EFI_HII_HANDLE instances returned.
 
-  @retval EFI_SUCCESS           The matching handles are outputed successfully.
+  @retval EFI_SUCCESS           The matching handles are outputted 
successfully.
                                 HandleBufferLength is updated with the actual 
length.
   @retval EFI_BUFFER_TOO_SMALL  The HandleBufferLength parameter
                                 indicates that Handle is too
@@ -273,7 +273,7 @@ EFI_STATUS
   
   @retval EFI_OUT_OF_RESOURCES  BufferSize is too small to hold the package.
 
-  @retval EFI_NOT_FOUND         The specifiecd Handle could not be found in the
+  @retval EFI_NOT_FOUND         The specified Handle could not be found in the
                                 current database.
   
   @retval EFI_INVALID_PARAMETER BufferSize was NULL.
diff --git a/MdePkg/Include/Protocol/Kms.h b/MdePkg/Include/Protocol/Kms.h
index 1a13755..da27096 100644
--- a/MdePkg/Include/Protocol/Kms.h
+++ b/MdePkg/Include/Protocol/Kms.h
@@ -1197,12 +1197,12 @@ struct _EFI_KMS_PROTOCOL {
   ///
   BOOLEAN                           ServiceAvailable;
   ///
-  /// TURE if and only if the service supports client identifiers. Client 
identifiers may be used
+  /// TRUE if and only if the service supports client identifiers. Client 
identifiers may be used
   /// for auditing, access control or any other purpose specific to the 
implementation.
   ///
   BOOLEAN                           ClientIdSupported;
   ///
-  /// TURE if and only if the service requires a client identifier in order to 
process key requests.
+  /// TRUE if and only if the service requires a client identifier in order to 
process key requests.
   /// FALSE otherwise.
   ///
   BOOLEAN                           ClientIdRequired;
@@ -1218,7 +1218,7 @@ struct _EFI_KMS_PROTOCOL {
   ///
   UINT8                             ClientNameStringTypes;
   ///
-  /// TURE if only if the KMS requires a client name to be supplied to the 
service.
+  /// TRUE if only if the KMS requires a client name to be supplied to the 
service.
   /// FALSE otherwise.
   ///
   BOOLEAN                           ClientNameRequired;
@@ -1227,7 +1227,7 @@ struct _EFI_KMS_PROTOCOL {
   ///
   UINT16                            ClientNameMaxCount;
   ///
-  /// TURE if and only if the service supports arbitrary client data requests. 
The use of client
+  /// TRUE if and only if the service supports arbitrary client data requests. 
The use of client
   /// data requires the caller to have specific knowledge of the individual 
KMS service and
   /// should be used only if absolutely necessary.
   /// FALSE otherwise.
@@ -1239,7 +1239,7 @@ struct _EFI_KMS_PROTOCOL {
   ///
   UINTN                             ClientDataMaxSize;
   ///
-  /// TURE if variable length key identifiers are supported.
+  /// TRUE if variable length key identifiers are supported.
   /// FALSE if a fixed length key identifier is supported.
   ///
   BOOLEAN                           KeyIdVariableLenSupported;
diff --git 
a/MdePkg/Library/BaseUefiDecompressLib/BaseUefiDecompressLibInternals.h 
b/MdePkg/Library/BaseUefiDecompressLib/BaseUefiDecompressLibInternals.h
index aba510c..4e14313 100644
--- a/MdePkg/Library/BaseUefiDecompressLib/BaseUefiDecompressLibInternals.h
+++ b/MdePkg/Library/BaseUefiDecompressLib/BaseUefiDecompressLibInternals.h
@@ -146,7 +146,7 @@ DecodeP (
 /**
   Reads code lengths for the Extra Set or the Position Set.
 
-  Read in the Extra Set or Pointion Set Length Arrary, then
+  Read in the Extra Set or Position Set Length Array, then
   generate the Huffman code mapping for them.
 
   @param  Sd      The global scratch data.
diff --git 
a/MdePkg/Library/DxeExtractGuidedSectionLib/DxeExtractGuidedSectionLib.c 
b/MdePkg/Library/DxeExtractGuidedSectionLib/DxeExtractGuidedSectionLib.c
index 567f091..8b8e528 100644
--- a/MdePkg/Library/DxeExtractGuidedSectionLib/DxeExtractGuidedSectionLib.c
+++ b/MdePkg/Library/DxeExtractGuidedSectionLib/DxeExtractGuidedSectionLib.c
@@ -179,7 +179,7 @@ ExtractGuidedSectionRegisterHandlers (
   VOID   *GuidData;
 
   //
-  // Check input paramter.
+  // Check input parameter.
   //
   ASSERT (SectionGuid != NULL);
   ASSERT (GetInfoHandler != NULL);
diff --git a/MdePkg/Library/DxeIoLibCpuIo2/IoLib.c 
b/MdePkg/Library/DxeIoLibCpuIo2/IoLib.c
index 9204757..110f66c 100644
--- a/MdePkg/Library/DxeIoLibCpuIo2/IoLib.c
+++ b/MdePkg/Library/DxeIoLibCpuIo2/IoLib.c
@@ -88,7 +88,7 @@ IoReadWorker (
   @param  Width         The width of the I/O operation.
   @param  Data          The value to write to the I/O port.
 
-  @return The paramter of Data.
+  @return The parameter of Data.
 
 **/
 UINT64
diff --git a/MdePkg/Library/DxeIoLibEsal/IoLib.c 
b/MdePkg/Library/DxeIoLibEsal/IoLib.c
index 81b28ec..3a58b51 100644
--- a/MdePkg/Library/DxeIoLibEsal/IoLib.c
+++ b/MdePkg/Library/DxeIoLibEsal/IoLib.c
@@ -68,7 +68,7 @@ IoReadWorker (
   @param  Width         The width of the I/O operation.
   @param  Data          The value to write to the I/O port.
 
-  @return The paramter of Data.
+  @return The parameter of Data.
 
 **/
 UINT64
diff --git a/MdePkg/Library/DxePciLibEsal/PciLib.c 
b/MdePkg/Library/DxePciLibEsal/PciLib.c
index 43fcef1..28b01c9 100644
--- a/MdePkg/Library/DxePciLibEsal/PciLib.c
+++ b/MdePkg/Library/DxePciLibEsal/PciLib.c
@@ -124,7 +124,7 @@ DxePciLibEsalReadWorker (
   This function wraps EsalPciConfigWrite function of Extended SAL PCI
   Services Class.
   It writes the PCI configuration register specified by Address with the
-  value specified by Data. The width of data is specifed by Width.
+  value specified by Data. The width of data is specified by Width.
   Data is returned.
 
   @param  Address Address that encodes the PCI Bus, Device, Function and
diff --git a/MdePkg/Library/DxePciSegmentLibEsal/PciLib.c 
b/MdePkg/Library/DxePciSegmentLibEsal/PciLib.c
index 07ddd8f..fe0fb8b 100644
--- a/MdePkg/Library/DxePciSegmentLibEsal/PciLib.c
+++ b/MdePkg/Library/DxePciSegmentLibEsal/PciLib.c
@@ -124,7 +124,7 @@ DxePciSegmentLibEsalReadWorker (
   This function wraps EsalPciConfigWrite function of Extended SAL PCI
   Services Class.
   It writes the PCI configuration register specified by Address with the
-  value specified by Data. The width of data is specifed by Width.
+  value specified by Data. The width of data is specified by Width.
   Data is returned.
 
   @param  Address Address that encodes the PCI Bus, Device, Function and
diff --git 
a/MdePkg/Library/PeiExtractGuidedSectionLib/PeiExtractGuidedSectionLib.c 
b/MdePkg/Library/PeiExtractGuidedSectionLib/PeiExtractGuidedSectionLib.c
index c471ae9..d7bc98b 100644
--- a/MdePkg/Library/PeiExtractGuidedSectionLib/PeiExtractGuidedSectionLib.c
+++ b/MdePkg/Library/PeiExtractGuidedSectionLib/PeiExtractGuidedSectionLib.c
@@ -198,7 +198,7 @@ ExtractGuidedSectionRegisterHandlers (
   PEI_EXTRACT_GUIDED_SECTION_HANDLER_INFO *HandlerInfo;
 
   //
-  // Check input paramter
+  // Check input parameter
   //
   ASSERT (SectionGuid != NULL);
   ASSERT (GetInfoHandler != NULL);
@@ -305,7 +305,7 @@ ExtractGuidedSectionGetInfo (
   EFI_GUID *SectionDefinitionGuid;
   
   //
-  // Check input paramter
+  // Check input parameter
   //
   ASSERT (InputSection != NULL);
   ASSERT (OutputBufferSize != NULL);
diff --git a/MdePkg/Library/PeiPciLibPciCfg2/PciLib.c 
b/MdePkg/Library/PeiPciLibPciCfg2/PciLib.c
index 689a229..ce9121b 100644
--- a/MdePkg/Library/PeiPciLibPciCfg2/PciLib.c
+++ b/MdePkg/Library/PeiPciLibPciCfg2/PciLib.c
@@ -90,7 +90,7 @@ PeiPciLibPciCfg2ReadWorker (
 
   This function wraps EFI_PEI_PCI_CFG2_PPI.Write() service.
   It writes the PCI configuration register specified by Address with the
-  value specified by Data. The width of data is specifed by Width.
+  value specified by Data. The width of data is specified by Width.
   Data is returned.
 
   @param  Address The address that encodes the PCI Bus, Device, Function and
diff --git a/MdePkg/Library/SmmIoLibSmmCpuIo2/IoLib.c 
b/MdePkg/Library/SmmIoLibSmmCpuIo2/IoLib.c
index 1e55791..7c8a603 100644
--- a/MdePkg/Library/SmmIoLibSmmCpuIo2/IoLib.c
+++ b/MdePkg/Library/SmmIoLibSmmCpuIo2/IoLib.c
@@ -58,7 +58,7 @@ IoReadWorker (
   @param  Width         The width of the I/O operation.
   @param  Data          The value to write to the I/O port.
 
-  @return The paramter of Data.
+  @return The parameter of Data.
 
 **/
 UINT64
diff --git a/MdePkg/Library/SmmMemoryAllocationLib/MemoryAllocationLib.c 
b/MdePkg/Library/SmmMemoryAllocationLib/MemoryAllocationLib.c
index 30670bf..937165a 100644
--- a/MdePkg/Library/SmmMemoryAllocationLib/MemoryAllocationLib.c
+++ b/MdePkg/Library/SmmMemoryAllocationLib/MemoryAllocationLib.c
@@ -114,7 +114,7 @@ SmmMemoryAllocationLibDestructor (
 
   @param[in]  Buffer   The pointer to the buffer to be checked.
 
-  @retval     TURE     The buffer is in SMRAM ranges.
+  @retval     TRUE     The buffer is in SMRAM ranges.
   @retval     FALSE    The buffer is out of SMRAM ranges.
 **/
 BOOLEAN
diff --git a/MdePkg/Library/SmmPciLibPciRootBridgeIo/PciLib.c 
b/MdePkg/Library/SmmPciLibPciRootBridgeIo/PciLib.c
index 0b94aeb..cdd35c1 100644
--- a/MdePkg/Library/SmmPciLibPciRootBridgeIo/PciLib.c
+++ b/MdePkg/Library/SmmPciLibPciRootBridgeIo/PciLib.c
@@ -112,7 +112,7 @@ SmmPciLibPciRootBridgeIoReadWorker (
 
   This function wraps EFI_PCI_ROOT_BRIDGE_IO_PROTOCOL.Pci.Write() service.
   It writes the PCI configuration register specified by Address with the
-  value specified by Data. The width of data is specifed by Width.
+  value specified by Data. The width of data is specified by Width.
   Data is returned.
 
   @param  Address The address that encodes the PCI Bus, Device, Function and
diff --git a/MdePkg/Library/SmmPeriodicSmiLib/SmmPeriodicSmiLib.c 
b/MdePkg/Library/SmmPeriodicSmiLib/SmmPeriodicSmiLib.c
index b6db317..2016af6 100644
--- a/MdePkg/Library/SmmPeriodicSmiLib/SmmPeriodicSmiLib.c
+++ b/MdePkg/Library/SmmPeriodicSmiLib/SmmPeriodicSmiLib.c
@@ -545,7 +545,7 @@ PeriodicSmiExit (
   If this function is not called from within an enabled periodic SMI handler, 
   then 0 is returned.
 
-  @return  The actual time in 100ns units elasped since this function was
+  @return  The actual time in 100ns units elapsed since this function was
            called.  A value of 0 indicates an unknown amount of time.
 
 **/
diff --git a/MdePkg/Library/UefiPciLibPciRootBridgeIo/PciLib.c 
b/MdePkg/Library/UefiPciLibPciRootBridgeIo/PciLib.c
index 148e12c..a146000 100644
--- a/MdePkg/Library/UefiPciLibPciRootBridgeIo/PciLib.c
+++ b/MdePkg/Library/UefiPciLibPciRootBridgeIo/PciLib.c
@@ -114,7 +114,7 @@ DxePciLibPciRootBridgeIoReadWorker (
 
   This function wraps EFI_PCI_ROOT_BRIDGE_IO_PROTOCOL.Pci.Write() service.
   It writes the PCI configuration register specified by Address with the
-  value specified by Data. The width of data is specifed by Width.
+  value specified by Data. The width of data is specified by Width.
   Data is returned.
 
   @param  Address The address that encodes the PCI Bus, Device, Function and
diff --git a/MdePkg/Library/BaseUefiDecompressLib/BaseUefiDecompressLib.c 
b/MdePkg/Library/BaseUefiDecompressLib/BaseUefiDecompressLib.c
index 4b86f50..e3b2846 100644
--- a/MdePkg/Library/BaseUefiDecompressLib/BaseUefiDecompressLib.c
+++ b/MdePkg/Library/BaseUefiDecompressLib/BaseUefiDecompressLib.c
@@ -308,7 +308,7 @@ DecodeP (
 /**
   Reads code lengths for the Extra Set or the Position Set.
 
-  Read in the Extra Set or Pointion Set Length Arrary, then
+  Read in the Extra Set or Position Set Length Array, then
   generate the Huffman code mapping for them.
 
   @param  Sd      The global scratch data.
@@ -508,7 +508,7 @@ DecodeC (
     Sd->mBlockSize    = (UINT16) GetBits (Sd, 16);
 
     //
     // Read in the Extra Set Code Length Arrary,
     // Generate the Huffman code mapping table for Extra Set.
     //
     Sd->mBadTableFlag = ReadPTLen (Sd, NT, TBIT, 3);
@@ -517,13 +517,13 @@ DecodeC (
     }
 
     //
     // Read in and decode the Char&Len Set Code Length Arrary,
     // Generate the Huffman code mapping table for Char&Len Set.
     //
     ReadCLen (Sd);
 
     //
     // Read in the Position Set Code Length Arrary, 
     // Generate the Huffman code mapping table for the Position Set.
     //
     Sd->mBadTableFlag = ReadPTLen (Sd, MAXNP, Sd->mPBit, (UINT16) (-1));
@@ -508,7 +508,7 @@ DecodeC (
 
     //
-    // Read in the Extra Set Code Length Arrary,
+    // Read in the Extra Set Code Length Array,
     // Generate the Huffman code mapping table for Extra Set.
     //
@@ -517,13 +517,13 @@ DecodeC (
 
     //
-    // Read in and decode the Char&Len Set Code Length Arrary,
+    // Read in and decode the Char&Len Set Code Length Array,
     // Generate the Huffman code mapping table for Char&Len Set.
     //
@@ -517,13 +517,13 @@ DecodeC (
 
     //
-    // Read in the Position Set Code Length Arrary, 
+    // Read in the Position Set Code Length Array,
     // Generate the Huffman code mapping table for the Position Set.
     //
-- 
2.10.1

_______________________________________________
edk2-devel mailing list
edk2-devel@lists.01.org
https://lists.01.org/mailman/listinfo/edk2-devel

Reply via email to